==> pythoncard_0.8.1.orig.tar.gz: PythonCard-0.8.1/tools/resourceEditor/resourceEditor.rsrc.py <==
{'application':{'type':'Application',
          'name':'ResEdit',
    'backgrounds': [
    {'type':'Background',
          'name':'bgDrag',
          'title':'Resource Editor',
          'size':(316, 166),
          'style':['resizeable'],

        'menubar': {'type':'MenuBar',
         'menus': [
             {'type':'Menu',
             'name':'menuFile',
             'label':'&File',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuFileNew',
                   'label':'&New...\tCtrl+N',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileOpen',
                   'label':'&Open...\tCtrl+O',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileSave',
                   'label':'Save\tCtrl+S',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileSaveAs',
                   'label':'Save &As...',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRevert',
                   'label':'Revert',
                  },
                  {'type':'MenuItem',
                   'name':'fileSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRun',
                   'label':'&Run\tCtrl+R',
                   'command':'fileRun',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRunWithInterpreter',
                   'label':'Run with &interpreter\tCtrl+Shift+R',
                   'command':'fileRunWithInterpreter',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRunOptions',
                   'label':'Run Options...',
                   'command':'fileRunOptions',
                  },
                  {'type':'MenuItem',
                   'name':'menuFilePreviewDialog',
                   'label':'Preview Dialog',
                   'command':'filePreviewDialog',
                  },
                  {'type':'MenuItem',
                   'name':'fileSep2',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileExit',
                   'label':'E&xit\tAlt+X',
                   'command':'exit',
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuEdit',
             'label':'&Edit',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuEditCut',
                   'label':'Cu&t\tCtrl+X',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditCopy',
                   'label':'&Copy\tCtrl+C',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditPaste',
                   'label':'&Paste\tCtrl+V',
                  },
                  {'type':'MenuItem',
                   'name':'editSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentDuplicate',
                   'label':'&Duplicate',
                   'command':'componentDuplicate',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentDelete',
                   'label':'Delete\tDel',
                   'command':'componentDelete',
                  },
                  {'type':'MenuItem',
                   'name':'componentSep2',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditBackgroundInfo',
                   'label':'Background Info...',
                   'command':'editBackgroundInfo',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditMenubar',
                   'label':'Menu Editor...',
                   'command':'editMenubar',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditStrings',
                   'label':'String Editor...',
                   'command':'editStrings',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditDialogInfo',
                   'label':'Dialog Info...',
                   'command':'editDialogInfo',
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuComponent',
             'label':'&Component',
             'items': []
             },
             {'type':'Menu',
             'name':'menuOptions',
             'label':'&Options',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuOptionsGridSize',
                   'label':'Grid Size...',
                   'command':'optionGridSize',
                  },
                  {'type':'MenuItem',
                   'name':'menuOptionsAlignToGrid',
                   'label':'Align Components to Grid\tCtrl+G',
                   'checkable':1,
                  },
                  {'type':'MenuItem',
                   'name':'menuOptionsShowGridLines',
                   'label':'Show Grid Lines',
                   'checkable':1,
                   'checked':0,
                  },
                  {'type':'MenuItem',
                   'name':'componentSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentSendBack',
                   'label':'Send to Back\tCtrl+1',
                   'command':'componentSendBack',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentMoveBack',
                   'label':'Move Backward\tCtrl+2',
                   'command':'componentMoveBack',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentMoveForward',
                   'label':'Move Forward\tCtrl+3',
                   'command':'componentMoveForward',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentBringFront',
                   'label':'Bring to Front\tCtrl+4',
                   'command':'componentBringFront',
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuView',
             'label':'&View',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuViewAttributes',
                   'label':'&Resource...',
                   'command':'displayAttributes',
                  },
                  {'type':'MenuItem',
                   'name':'menuViewSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuViewPropertyEditor',
                   'label':'Property Editor\tCtrl+P',
                   'checkable':1,
                   'checked':1,
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuHelp',
             'label':'&Help',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuResourceEditorDocumentation',
                   'label':'&resourceEditor Documentation...\tF1',
                   'command':'showResourceEditorDocumentation',
                  },
                  {'type':'MenuItem',
                   'name':'menuPythonCardDocumentation',
                   'label':'&PythonCard Documentation...',
                   'command':'showPythonCardDocumentation',
                  },
                  {'type':'MenuItem',
                   'name':'helpSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuHelpAbout',
                   'label':'&About resourceEditor...',
                  },
                  {'type':'MenuItem',
                   'name':'menuHelpAboutPythonCard',
                   'label':'About PythonCard...',
                   'command':'doHelpAboutPythonCard',
                  },
              ]
             },
         ]
     },
         'components': [

] # end components
} # end background
] # end backgrounds
} }

==> pythoncard_0.8.2.orig.tar.gz: PythonCard-0.8.2/tools/resourceEditor/resourceEditor.rsrc.py <==
{'application':{'type':'Application',
          'name':'ResEdit',
    'backgrounds': [
    {'type':'Background',
          'name':'bgDrag',
          'title':'Resource Editor',
          'size':(316, 166),
          'style':['resizeable'],

        'menubar': {'type':'MenuBar',
         'menus': [
             {'type':'Menu',
             'name':'menuFile',
             'label':'&File',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuFileNew',
                   'label':'&New...\tCtrl+N',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileOpen',
                   'label':'&Open...\tCtrl+O',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileSave',
                   'label':'Save\tCtrl+S',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileSaveAs',
                   'label':'Save &As...',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRevert',
                   'label':'Revert',
                  },
                  {'type':'MenuItem',
                   'name':'fileSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRun',
                   'label':'&Run\tCtrl+R',
                   'command':'fileRun',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRunWithInterpreter',
                   'label':'Run with &interpreter\tCtrl+Shift+R',
                   'command':'fileRunWithInterpreter',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileRunOptions',
                   'label':'Run Options...',
                   'command':'fileRunOptions',
                  },
                  {'type':'MenuItem',
                   'name':'menuFilePreviewDialog',
                   'label':'Preview Dialog',
                   'command':'filePreviewDialog',
                  },
                  {'type':'MenuItem',
                   'name':'fileSep2',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuFileExit',
                   'label':'E&xit\tAlt+X',
                   'command':'exit',
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuEdit',
             'label':'&Edit',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuEditCut',
                   'label':'Cu&t\tCtrl+X',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditCopy',
                   'label':'&Copy\tCtrl+C',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditPaste',
                   'label':'&Paste\tCtrl+V',
                  },
                  {'type':'MenuItem',
                   'name':'editSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentDuplicate',
                   'label':'&Duplicate\tCtrl+U',
                   'command':'componentDuplicate',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentDelete',
                   'label':'Delete\tCtrl+D',
                   'command':'componentDelete',
                  },
                  {'type':'MenuItem',
                   'name':'componentSep2',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditBackgroundInfo',
                   'label':'Background Info...',
                   'command':'editBackgroundInfo',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditMenubar',
                   'label':'Menu Editor...',
                   'command':'editMenubar',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditStrings',
                   'label':'String Editor...',
                   'command':'editStrings',
                  },
                  {'type':'MenuItem',
                   'name':'menuEditDialogInfo',
                   'label':'Dialog Info...',
                   'command':'editDialogInfo',
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuComponent',
             'label':'&Component',
             'items': []
             },
             {'type':'Menu',
             'name':'menuOptions',
             'label':'&Options',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuOptionsGridSize',
                   'label':'Grid Size...',
                   'command':'optionGridSize',
                  },
                  {'type':'MenuItem',
                   'name':'menuOptionsAlignToGrid',
                   'label':'Align Components to Grid\tCtrl+G',
                   'checkable':1,
                  },
                  {'type':'MenuItem',
                   'name':'menuOptionsShowGridLines',
                   'label':'Show Grid Lines',
                   'checkable':1,
                   'checked':0,
                  },
                  {'type':'MenuItem',
                   'name':'componentSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentSendBack',
                   'label':'Send to Back\tCtrl+1',
                   'command':'componentSendBack',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentMoveBack',
                   'label':'Move Backward\tCtrl+2',
                   'command':'componentMoveBack',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentMoveForward',
                   'label':'Move Forward\tCtrl+3',
                   'command':'componentMoveForward',
                  },
                  {'type':'MenuItem',
                   'name':'menuComponentBringFront',
                   'label':'Bring to Front\tCtrl+4',
                   'command':'componentBringFront',
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuView',
             'label':'&View',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuViewAttributes',
                   'label':'&Resource...',
                   'command':'displayAttributes',
                  },
                  {'type':'MenuItem',
                   'name':'menuViewSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuViewPropertyEditor',
                   'label':'Property Editor\tCtrl+P',
                   'checkable':1,
                   'checked':1,
                  },
              ]
             },
             {'type':'Menu',
             'name':'menuHelp',
             'label':'&Help',
             'items': [
                  {'type':'MenuItem',
                   'name':'menuResourceEditorDocumentation',
                   'label':'&resourceEditor Documentation...\tF1',
                   'command':'showResourceEditorDocumentation',
                  },
                  {'type':'MenuItem',
                   'name':'menuPythonCardDocumentation',
                   'label':'&PythonCard Documentation...',
                   'command':'showPythonCardDocumentation',
                  },
                  {'type':'MenuItem',
                   'name':'helpSep1',
                   'label':'-',
                  },
                  {'type':'MenuItem',
                   'name':'menuHelpAbout',
                   'label':'&About resourceEditor...',
                  },
                  {'type':'MenuItem',
                   'name':'menuHelpAboutPythonCard',
                   'label':'About PythonCard...',
                   'command':'doHelpAboutPythonCard',
                  },
              ]
             },
         ]
     },
         'components': [

] # end components
} # end background
] # end backgrounds
} }
